@@ -50,6 +50,21 @@ then
   mkdir ${INSTALLDIR}/doc
   chmod 0755 ${INSTALLDIR}/doc
 fi
+if [ ! -d ${INSTALLDIR}/doc/img ]
+then
+  mkdir ${INSTALLDIR}/doc/img
+  chmod 0755 ${INSTALLDIR}/doc/img
+fi
+if [ ! -d ${INSTALLDIR}/doc/tutorial ]
+then
+  mkdir ${INSTALLDIR}/doc/tutorial
+  chmod 0755 ${INSTALLDIR}/doc/tutorial
+fi
+if [ ! -d ${INSTALLDIR}/doc/dialogs ]
+then
+  mkdir ${INSTALLDIR}/doc/dialogs
+  chmod 0755 ${INSTALLDIR}/doc/dialogs
+fi
 
 echo "Copying files to ${INSTALLDIR}"
 cp ${TEXTFILES} ${BINARIES} Ngraph ${INSTALLDIR}
@@ -87,6 +102,13 @@ echo "Copying demo files to ${INSTALLDIR}/demo"
  chmod 0644 ${DEMOFILES}
 )
 
+echo "Copying documents to ${INSTALLDIR}/doc"
+(cd x11help
+ cp -r * ${INSTALLDIR}/doc
+ cd ${INSTALLDIR}/doc
+ chmod 0644 *.htm img/* tutorial/* dialogs/*
+)
+
 if [ ! -h ${BINDIR}/ngraph ]
 then
   echo "Making a symbolic link ${BINDIR}/ngraph"
