@@ -1,5 +1,5 @@
 /* 
- * $Id: mathfn.c,v 1.5 2003/02/16 12:42:14 isizaka Exp isizaka $
+ * $Id: mathfn.c,v 1.4 2002/07/06 08:51:42 isizaka Exp isizaka $
  * 
  * This file is part of "Ngraph for X11".
  * 
@@ -24,9 +24,6 @@
 /**
  *
  * $Log: mathfn.c,v $
- * Revision 1.5  2003/02/16 12:42:14  isizaka
- * for release 6.13.18
- *
  * Revision 1.4  2002/07/06 08:51:42  isizaka
  * change to GPL.
  *
@@ -87,8 +84,8 @@ int nround(double x)
   int ix;
   double dx;
 
-  if (x>LONG_MAX) return LONG_MAX;
-  else if (x<LONG_MIN) return LONG_MIN;
+  if (x>INT_MAX) return INT_MAX;
+  else if (x<INT_MIN) return INT_MIN;
   else {
     ix=(int )x;
     dx=x-ix;
