@@ -233,7 +233,7 @@ int mergetime(struct objlist *obj,char *inst,char *rval,int argc,char **argv)
   if (file==NULL) return 0;
   if (stat(file,&buf)!=0) return 1;
   style=*(int *)(argv[2]);
-  *(char **)rval=ntime(&(buf.st_mtime),style);
+  *(char **)rval=ntime((time_t *)&(buf.st_mtime),style);
   return 0;
 }
 
@@ -249,7 +249,7 @@ int mergedate(struct objlist *obj,char *inst,char *rval,int argc,char **argv)
   if (file==NULL) return 0;
   if (stat(file,&buf)!=0) return 1;
   style=*(int *)(argv[2]);
-  *(char **)rval=ndate(&(buf.st_mtime),style);
+  *(char **)rval=ndate((time_t *)&(buf.st_mtime),style);
   return 0;
 }
 
