@@ -1,5 +1,5 @@
-/* 
- * $Id: osystem.c,v 1.10 2004/08/07 13:03:52 isizaka Exp $
+/*
+ * $Id: osystem.c,v 1.8 2002/07/06 08:51:42 isizaka Exp isizaka $
  * 
  * This file is part of "Ngraph for X11".
  * 
@@ -24,9 +24,6 @@
 /**
  *
  * $Log: osystem.c,v $
- * Revision 1.10  2004/08/07 13:03:52  isizaka
- * resize function
- *
  * Revision 1.8  2002/07/06 08:51:42  isizaka
  * change to GPL.
  *
@@ -61,9 +58,11 @@
 #ifndef WINDOWS
 #include <unistd.h>
 #else
-#include <dir.h>
+#ifdef DEBUG
 #include <dos.h>
 #endif
+#include <dir.h>
+#endif
 #include "ngraph.h"
 #include "object.h"
 #include "ioutil.h"
@@ -73,7 +72,7 @@
 #define PARENT   "object"
 #define SYSNAME  "Ngraph"
 #define TEMPN    "NGP"
-#define COPYRIGHT "Copyright (C) 2003, Satoshi ISHIZAKA."
+#define COPYRIGHT "Copyright (C) 2015, Satoshi ISHIZAKA."
 #define EMAIL "isizaka@msa.biglobe.ne.jp"
 #ifndef WINDOWS
 #define WEB "http://www2e.biglobe.ne.jp/~isizaka/"
