@@ -1,5 +1,5 @@
 /* 
- * $Id: shell.c,v 1.9 2009/10/15 11:14:16 isizaka Exp isizaka $
+ * $Id: shell.c,v 1.7 2002/07/06 08:51:42 isizaka Exp isizaka $
  * 
  * This file is part of "Ngraph for X11".
  * 
@@ -24,9 +24,6 @@
 /**
  *
  * $Log: shell.c,v $
- * Revision 1.9  2009/10/15 11:14:16  isizaka
- * ${%} etc were implemented
- *
  * Revision 1.7  2002/07/06 08:51:42  isizaka
  * change to GPL.
  *
@@ -1745,11 +1742,11 @@ char *expand(struct nshell *nshell,char *str,int *quote,int *bquote,
             }
             if (valf2=='%') {
               for (k=0;k<=strlen(c2)-1;k++) {
-                if (wildmatch(c1,c2+k,WILD_PATHNAME|WILD_PERIOD)) break;
+                if (wildmatch(c1,c2+k,WILD_PATHNAME)) break;
               }
             } else {
               for (k=strlen(c2);k>=0;k--) {
-                if (wildmatch(c1,c2+k,WILD_PATHNAME|WILD_PERIOD)) break;
+                if (wildmatch(c1,c2+k,WILD_PATHNAME)) break;
               }
             }
             if (k<0) k=strlen(c2);
@@ -2008,7 +2005,6 @@ int checkcmd(struct nshell *nshell,struct cmdlist **cmdroot)
               else 
                 prmcur->prmno=PPSI1;
             }
-
             (prmcur->next)->prmno=prmcur->prmno;
             prmcur=prmcur->next;
           } else if (prmcur->str[0]=='|') {
