@@ -1,5 +1,5 @@
 /* 
- * $Id: shellcm.c,v 1.6 2003/02/16 12:42:14 isizaka Exp isizaka $
+ * $Id: shellcm.c,v 1.5 2002/07/06 08:51:42 isizaka Exp isizaka $
  * 
  * This file is part of "Ngraph for X11".
  * 
@@ -24,9 +24,6 @@
 /**
  *
  * $Log: shellcm.c,v $
- * Revision 1.6  2003/02/16 12:42:14  isizaka
- * for release 6.13.18
- *
  * Revision 1.5  2002/07/06 08:51:42  isizaka
  * change to GPL.
  *
@@ -53,7 +50,6 @@
 #ifndef WINDOWS
 #include <unistd.h>
 #else
-#include <dos.h>
 #include <dir.h>
 #endif
 #include "ngraph.h"
