@@ -1,21 +1,41 @@
-/**
- *
- * $Id: x11axis.c,v 1.6 1999/05/08 13:31:30 isizaka Exp $
- *
- * Copyright (C) 1997, Satoshi ISHIZAKA.
- *
- * This file is part of Ngraph
- *
- * This is free software; you can redistribute it and/or modify it.
- * However, it is prohibited to compile this on the "Windows" environment.
- *
- * Original author: Satoshi ISHIZAKA
- *                  isizaka@msa.biglobe.ne.jp
- **/
+/* 
+ * $Id: x11axis.c,v 1.10 2003/02/16 12:43:37 isizaka Exp isizaka $
+ * 
+ * This file is part of "Ngraph for X11".
+ * 
+ * Copyright (C) 2002, Satoshi ISHIZAKA. isizaka@msa.biglobe.ne.jp
+ * 
+ * "Ngraph for X11" is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * "Ngraph for X11" is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ */
 
 /**
  *
  * $Log: x11axis.c,v $
+ * Revision 1.10  2003/02/16 12:43:37  isizaka
+ * for release 6.13.18
+ *
+ * Revision 1.9  2002/07/06 08:57:25  isizaka
+ * change to GPL.
+ *
+ * Revision 1.8  2001/03/23 12:17:43  isizaka
+ * for 6.3.13
+ *
+ * Revision 1.7  2000/10/28 14:48:05  isizaka
+ * AxisDialogFile: type is preserved.
+ *
  * Revision 1.6  1999/05/08 13:31:30  isizaka
  * for release 6.03.02
  *
@@ -108,6 +128,8 @@ void GridDialogSetupItem(Widget w,struct GridDialog *d,int id)
     XmListAddItem(GetComboBoxList(w,"*axisy"),xs,0);
     XmStringFree(xs);
   }
+  SetComboBoxVisibleItemCount(w,"*axisx",j);
+  SetComboBoxVisibleItemCount(w,"*axisy",j);
   sgetobjfield(d->Obj,id,"axis_x",NULL,&valstr,FALSE,FALSE,FALSE);
   for (i=0;(valstr[i]!='\0') && (valstr[i]!=':');i++);
   if (valstr[i]==':') i++;
@@ -123,10 +145,13 @@ void GridDialogSetupItem(Widget w,struct GridDialog *d,int id)
   SetStyleFromObjField(w,"*style3",d->Obj,id,"style3");
   SetComboList(w,"*wid1",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wid1"),NULL,d->Obj,id,"width1");
+  SetComboListFromObjField(GetComboBoxList(w,"*wid1"),NULL,d->Obj,id,"width1");
   SetComboList(w,"*wid2",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wid2"),NULL,d->Obj,id,"width2");
+  SetComboListFromObjField(GetComboBoxList(w,"*wid2"),NULL,d->Obj,id,"width2");
   SetComboList(w,"*wid3",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wid3"),NULL,d->Obj,id,"width3");
+  SetComboListFromObjField(GetComboBoxList(w,"*wid3"),NULL,d->Obj,id,"width3");
   SetToggleFromObjField(w,"*Background",d->Obj,id,"background");
   getobj(d->Obj,"R",id,0,NULL,&d->R);
   getobj(d->Obj,"G",id,0,NULL,&d->G);
@@ -995,6 +1020,7 @@ void AxisBaseDialogSetupItem(Widget w,struct AxisBaseDialog *d,int id)
   SetStyleFromObjField(w,"*style",d->Obj,id,"style");
   SetComboList(w,"*width",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*width"),NULL,d->Obj,id,"width");
+  SetComboListFromObjField(GetComboBoxList(w,"*width"),NULL,d->Obj,id,"width");
   SetToggleFromObjField(w,"*Baseline",d->Obj,id,"baseline");
   SetListFromObjField(w,"*arrow",d->Obj,id,"arrow");
   SetTextFromObjField(w,"*arrowlen",d->Obj,id,"arrow_length");
@@ -1004,6 +1030,8 @@ void AxisBaseDialogSetupItem(Widget w,struct AxisBaseDialog *d,int id)
   SetComboList(w,"*wavewid",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wavewid"),NULL,
                       d->Obj,id,"wave_width");
+  SetComboListFromObjField(GetComboBoxList(w,"*wavewid"),NULL,
+                      d->Obj,id,"wave_width");
   getobj(d->Obj,"R",id,0,NULL,&d->R);
   getobj(d->Obj,"G",id,0,NULL,&d->G);
   getobj(d->Obj,"B",id,0,NULL,&d->B);
@@ -1152,6 +1180,8 @@ void AxisPosDialogSetupItem(Widget w,struct AxisPosDialog *d,int id)
   SetComboList(w,"*direction",cbdirection,CBDIRECTION);
   SetTextFromObjField(GetComboBoxText(w,"*direction"),NULL,
                       d->Obj,id,"direction");
+  SetComboListFromObjField(GetComboBoxList(w,"*direction"),NULL,
+                      d->Obj,id,"direction");
   lastinst=chkobjlastinst(d->Obj);
   for (j=0;j<=lastinst;j++) {
     getobj(d->Obj,"group",j,0,NULL,&name);
@@ -1160,6 +1190,7 @@ void AxisPosDialogSetupItem(Widget w,struct AxisPosDialog *d,int id)
     XmListAddItem(GetComboBoxList(w,"*adjust"),xs,0);
     XmStringFree(xs);
   }
+  SetComboBoxVisibleItemCount(w,"*adjust",j);
   sgetobjfield(d->Obj,id,"adjust_axis",NULL,&valstr,FALSE,FALSE,FALSE);
   for (i=0;(valstr[i]!='\0') && (valstr[i]!=':');i++);
   if (valstr[i]==':') i++;
@@ -1314,6 +1345,7 @@ void NumDialogSetupItem(Widget w,struct NumDialog *d,int id)
     XmListAddItem(GetComboBoxList(w,"*fraction"),xs,0);
     XmStringFree(xs);
   }
+  SetComboBoxVisibleItemCount(w,"*fraction",j);
   getobj(d->Obj,"num_format",id,0,NULL,&format);
   if (strchr(format,'+')!=NULL)
      XmToggleButtonSetState(XtNameToWidget(w,"*Add_plus"),TRUE,TRUE);
@@ -1518,6 +1550,7 @@ void AxisFontDialogSetupItem(Widget w,struct AxisFontDialog *d,int id)
   SetTextFromObjField(w,"*space",d->Obj,id,"num_space");
   SetComboList(w,"*pt",cbtextpt,CBTEXTPT);
   SetTextFromObjField(GetComboBoxText(w,"*pt"),NULL,d->Obj,id,"num_pt");
+  SetComboListFromObjField(GetComboBoxList(w,"*pt"),NULL,d->Obj,id,"num_pt");
   SetTextFromObjField(w,"*script",d->Obj,id,"num_script_size");
   getobj(d->Obj,"num_font",id,0,NULL,&font);
   XmListDeleteAllItems(GetComboBoxList(w,"*font"));
@@ -1534,6 +1567,7 @@ void AxisFontDialogSetupItem(Widget w,struct AxisFontDialog *d,int id)
     }
     fcur=fcur->next;
   }
+  SetComboBoxVisibleItemCount(w,"*font",j);
   if (selfont!=-1) 
     XmListSelectPos(GetComboBoxList(w,"*font"),selfont+1,TRUE);
 #ifdef JAPANESE
@@ -1552,6 +1586,7 @@ void AxisFontDialogSetupItem(Widget w,struct AxisFontDialog *d,int id)
     }
     fcur=fcur->next;
   }
+  SetComboBoxVisibleItemCount(w,"*jfont",j);
   if (selfont!=-1) 
     XmListSelectPos(GetComboBoxList(w,"*jfont"),selfont+1,TRUE);
 #endif
@@ -1721,14 +1756,20 @@ void GaugeDialogSetupItem(Widget w,struct GaugeDialog *d,int id)
   SetComboList(w,"*wid1",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wid1"),NULL,
                       d->Obj,id,"gauge_width1");
+  SetComboListFromObjField(GetComboBoxList(w,"*wid1"),NULL,
+                      d->Obj,id,"gauge_width1");
   SetTextFromObjField(w,"*len2",d->Obj,id,"gauge_length2");
   SetComboList(w,"*wid2",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wid2"),NULL,
                       d->Obj,id,"gauge_width2");
+  SetComboListFromObjField(GetComboBoxList(w,"*wid2"),NULL,
+                      d->Obj,id,"gauge_width2");
   SetTextFromObjField(w,"*len3",d->Obj,id,"gauge_length3");
   SetComboList(w,"*wid3",cblinewidth,CBLINEWIDTH);
   SetTextFromObjField(GetComboBoxText(w,"*wid3"),NULL,
                       d->Obj,id,"gauge_width3");
+  SetComboListFromObjField(GetComboBoxList(w,"*wid3"),NULL,
+                      d->Obj,id,"gauge_width3");
   getobj(d->Obj,"gauge_R",id,0,NULL,&d->R);
   getobj(d->Obj,"gauge_G",id,0,NULL,&d->G);
   getobj(d->Obj,"gauge_B",id,0,NULL,&d->B);
@@ -1907,35 +1948,40 @@ void AxisDialogSetupItem(Widget w,struct AxisDialog *d,int id)
     num=arraynum(array)/3;
     data=(double *)arraydata(array);
     for (j=0;j<num;j++) {
-      sprintf(buf,"%.15e",data[0+j*3]);
+      sprintf(buf,"%.15g",data[0+j*3]);
       xs=XmStringCreateLocalized(buf);
       XmListAddItem(GetComboBoxList(w,"*min"),xs,0);
       XmStringFree(xs);
-      sprintf(buf,"%.15e",data[1+j*3]);
+      sprintf(buf,"%.15g",data[1+j*3]);
       xs=XmStringCreateLocalized(buf);
       XmListAddItem(GetComboBoxList(w,"*max"),xs,0);
       XmStringFree(xs);
-      sprintf(buf,"%.15e",data[2+j*3]);
+      sprintf(buf,"%.15g",data[2+j*3]);
       xs=XmStringCreateLocalized(buf);
       XmListAddItem(GetComboBoxList(w,"*inc"),xs,0);
       XmStringFree(xs);
     }
+    SetComboBoxVisibleItemCount(w,"*min",j);
+    SetComboBoxVisibleItemCount(w,"*max",j);
+    SetComboBoxVisibleItemCount(w,"*inc",j);
   }
   getobj(d->Obj,"min",id,0,NULL,&min);
   getobj(d->Obj,"max",id,0,NULL,&max);
   getobj(d->Obj,"inc",id,0,NULL,&inc);
-  getobj(d->Obj,"div",id,0,NULL,&div);
-  if ((min==0) && (max==0) && (inc==0) && (div==0)) {
+  if ((min==0) && (max==0) && (inc==0)) {
     XtVaSetValues(GetComboBoxText(w,"*min"),XmNvalue,"0",NULL);
     XtVaSetValues(GetComboBoxText(w,"*max"),XmNvalue,"0",NULL);
     XtVaSetValues(GetComboBoxText(w,"*inc"),XmNvalue,"0",NULL);
-    XtVaSetValues(XtNameToWidget(w,"*div"),XmNvalue,"0",NULL);
   } else {
-    SetTextFromObjField(GetComboBoxText(w,"*min"),NULL,d->Obj,id,"min");
-    SetTextFromObjField(GetComboBoxText(w,"*max"),NULL,d->Obj,id,"max");
-    SetTextFromObjField(GetComboBoxText(w,"*inc"),NULL,d->Obj,id,"inc");
-    SetTextFromObjField(w,"*div",d->Obj,id,"div");
+    sprintf(buf,"%.15g",min);
+    XtVaSetValues(GetComboBoxText(w,"*min"),XmNvalue,buf,NULL);
+    sprintf(buf,"%.15g",max);
+    XtVaSetValues(GetComboBoxText(w,"*max"),XmNvalue,buf,NULL);
+    sprintf(buf,"%.15g",inc);
+    XtVaSetValues(GetComboBoxText(w,"*inc"),XmNvalue,buf,NULL);
   }
+  getobj(d->Obj,"div",id,0,NULL,&div);
+  SetTextFromObjField(w,"*div",d->Obj,id,"div");
   SetListFromObjField(w,"*scale",d->Obj,id,"type");
   XmListDeleteAllItems(GetComboBoxList(w,"*ref"));
   lastinst=chkobjlastinst(d->Obj);
@@ -1946,6 +1992,7 @@ void AxisDialogSetupItem(Widget w,struct AxisDialog *d,int id)
     XmListAddItem(GetComboBoxList(w,"*ref"),xs,0);
     XmStringFree(xs);
   }
+  SetComboBoxVisibleItemCount(w,"*ref",j);
   sgetobjfield(d->Obj,id,"reference",NULL,&valstr,FALSE,FALSE,FALSE);
   for (i=0;(valstr[i]!='\0') && (valstr[i]!=':');i++);
   if (valstr[i]==':') i++;
@@ -2007,13 +2054,12 @@ void AxisDialogClear(Widget w,XtPointer client_data,XtPointer call_data)
   XtVaSetValues(GetComboBoxText(d->widget,"*min"),XmNvalue,"0",NULL);
   XtVaSetValues(GetComboBoxText(d->widget,"*max"),XmNvalue,"0",NULL);
   XtVaSetValues(GetComboBoxText(d->widget,"*inc"),XmNvalue,"0",NULL);
-  XtVaSetValues(XtNameToWidget(d->widget,"*div"),XmNvalue,"0",NULL);
 }
 
 void AxisDialogFile(Widget w,XtPointer client_data,XtPointer call_data)
 {
   struct AxisDialog *d;
-  int anum,room;
+  int anum,room,type;
   char *buf,s[30];
   char *argv2[3];
   struct objlist *fobj;
@@ -2045,7 +2091,8 @@ void AxisDialogFile(Widget w,XtPointer client_data,XtPointer call_data)
         if (count!=0) {
           a=selected[0]-1;
           XtFree((char *)selected);
-          if (putobj(d->Obj,"type",d->Id,&a)==-1) {
+          if ((getobj(d->Obj,"type",d->Id,0,NULL,&type)==-1)
+          || (putobj(d->Obj,"type",d->Id,&a)==-1)) {
             arraydel(&farray);
             return;
           }
@@ -2053,13 +2100,14 @@ void AxisDialogFile(Widget w,XtPointer client_data,XtPointer call_data)
         getobj(d->Obj,"get_auto_scale",d->Id,2,argv2,&result);
         memfree(buf);
         if (arraynum(result)==3) {
-          sprintf(s,"%.15e",*(double *)arraynget(result,0));
+          sprintf(s,"%.15g",*(double *)arraynget(result,0));
           XtVaSetValues(GetComboBoxText(d->widget,"*min"),XmNvalue,s,NULL);
-          sprintf(s,"%.15e",*(double *)arraynget(result,1));
+          sprintf(s,"%.15g",*(double *)arraynget(result,1));
           XtVaSetValues(GetComboBoxText(d->widget,"*max"),XmNvalue,s,NULL);
-          sprintf(s,"%.15e",*(double *)arraynget(result,2));
+          sprintf(s,"%.15g",*(double *)arraynget(result,2));
           XtVaSetValues(GetComboBoxText(d->widget,"*inc"),XmNvalue,s,NULL);
         }
+        putobj(d->Obj,"type",d->Id,&type);
       }
     }
   }
@@ -3225,12 +3273,14 @@ void AxisWindowUnmap(Widget w,XtPointer client_data,XtPointer call_data)
 {
   struct AxisWin *d;
   Position x,y,x0,y0;
+  Dimension w0,h0;
 
   d=&(NgraphApp.AxisWin);
   if (d->Win!=NULL) {
     XtVaGetValues(d->Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.axiswidth),
-                         XmNheight,&(menulocal.axisheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+    menulocal.axiswidth=w0;
+    menulocal.axisheight=h0;
     XtTranslateCoords(TopLevel,0,0,&x0,&y0);
     menulocal.axisx=x-x0;
     menulocal.axisy=y-y0;
