@@ -75,7 +75,7 @@
 #include "object.h"
 #include "ioutil.h"
 #include "shell.h"
-#include "jstring.h"
+#include "jnstring.h"
 #include "nstring.h"
 #include "config.h"
 #include "mathfn.h"
@@ -688,14 +688,17 @@ int setwindowfont()
   char **missing,*defstring;
   int missingcount;
   XRectangle ink,logical;
+  XFontSetExtents *ext;
 
   FFont=XCreateFontSet(Disp,resources.windowfont,
                        &missing,&missingcount,&defstring);
   if (FFont==NULL) return FALSE;
   XFreeStringList(missing);
-  XmbTextExtents(FFont,"H",1,&ink,&logical);
+  ext=XExtentsOfFontSet(FFont);
+  logical=ext->max_logical_extent;
+  /*  XmbTextExtents(FFont,"H",1,&ink,&logical); */
   FAscent=-logical.y;
-  XmbTextExtents(FFont,"g",1,&ink,&logical);
+  /* XmbTextExtents(FFont,"g",1,&ink,&logical); */
   FDescent=logical.y+logical.height;
   FHeight=FAscent+FDescent;
   FWidth=XmbTextEscapement(FFont,"M",1);
