@@ -407,6 +407,17 @@ void MergeWinMergeUpdate()
   }
 }
 
+void MergeWinMergeSelect()
+{
+  int sel;
+  struct MergeWin *d;
+
+  d=&(NgraphApp.MergeWin);
+  if (menulock || globallock) return;
+  sel=d->select;
+  if ((sel>=0) && (sel<=d->filenum)) Focus(d->obj,sel);
+}
+
 void MergeWinMergeHidden()
 {
   int sel;
@@ -415,6 +426,7 @@ void MergeWinMergeHidden()
 
   d=&(NgraphApp.MergeWin);
   if (menulock || globallock) return;
+  UnFocus();
   sel=d->select;
   if ((sel>=0) && (sel<=d->filenum)) {
     getobj(d->obj,"hidden",sel,0,NULL,&hidden);
@@ -612,6 +624,7 @@ void MergeWinEvRButtonDown(unsigned int state,TPoint point,struct MergeWin *d,
     XtSetSensitive(XtNameToWidget(d->popup,"button_6"),True);
     XtSetSensitive(XtNameToWidget(d->popup,"button_7"),True);
     XtSetSensitive(XtNameToWidget(d->popup,"button_8"),True);
+    XtSetSensitive(XtNameToWidget(d->popup,"button_9"),True);
   } else {
     XtSetSensitive(XtNameToWidget(d->popup,"button_0"),True);
     XtSetSensitive(XtNameToWidget(d->popup,"button_1"),False);
@@ -622,6 +635,7 @@ void MergeWinEvRButtonDown(unsigned int state,TPoint point,struct MergeWin *d,
     XtSetSensitive(XtNameToWidget(d->popup,"button_6"),False);
     XtSetSensitive(XtNameToWidget(d->popup,"button_7"),False);
     XtSetSensitive(XtNameToWidget(d->popup,"button_8"),False);
+    XtSetSensitive(XtNameToWidget(d->popup,"button_9"),False);
   }
   XmMenuPosition(d->popup,event);
   XtManageChild(d->popup);
@@ -663,28 +677,31 @@ void MergeWinPopupMenu(Widget w,XtPointer client_data,XtPointer call_data)
   case 0:
     MergeWinMergeOpen(); 
     break;
-  case 1: 
-    MergeWinMergeUpdate(); 
+  case 1:
+    MergeWinMergeSelect(); 
     break;
   case 2: 
-    MergeWinMergeDelete(); 
+    MergeWinMergeUpdate(); 
     break;
   case 3: 
-    MergeWinMergeTop(); 
+    MergeWinMergeDelete(); 
     break;
   case 4: 
-    MergeWinMergeUp(); 
+    MergeWinMergeTop(); 
     break;
   case 5: 
-    MergeWinMergeDown(); 
+    MergeWinMergeUp(); 
     break;
   case 6: 
-    MergeWinMergeLast(); 
+    MergeWinMergeDown(); 
     break;
   case 7: 
-    MergeWinMergeCopy(); 
+    MergeWinMergeLast(); 
     break;
   case 8: 
+    MergeWinMergeCopy(); 
+    break;
+  case 9: 
     MergeWinMergeHidden(); 
     break;
   }
@@ -741,6 +758,9 @@ void MergeWinEvKeyDown(Widget w,XtPointer client_data,XEvent *event,
   case XK_Return:
     MergeWinMergeUpdate();
     break;
+  case XK_space:
+    MergeWinMergeSelect();
+    break;
   case XK_BackSpace:
     MergeWinMergeHidden();
     break;
@@ -844,6 +864,7 @@ void CmMergeWindow(Widget w,XtPointer client_data,XtPointer call_data)
     XmVaPUSHBUTTON,NULL,NULL,NULL,NULL,
     XmVaPUSHBUTTON,NULL,NULL,NULL,NULL,
     XmVaPUSHBUTTON,NULL,NULL,NULL,NULL,
+    XmVaPUSHBUTTON,NULL,NULL,NULL,NULL,
     NULL);
     XtAddEventHandler(d->text,KeyPressMask,False,MergeWinEvKeyDown,d);
     XmToggleButtonSetState(XtNameToWidget(TopLevel,"*windowmenu.button_3"),
