@@ -1,21 +1,41 @@
-/**
- *
- * $Id: x11opt.c,v 1.4 1999/04/11 06:09:20 isizaka Exp $
- *
- * Copyright (C) 1997, Satoshi ISHIZAKA.
- *
- * This file is part of Ngraph
- *
- * This is free software; you can redistribute it and/or modify it.
- * However, it is prohibited to compile this on the "Windows" environment.
- *
- * Original author: Satoshi ISHIZAKA
- *                  isizaka@msa.biglobe.ne.jp
- **/
+/* 
+ * $Id: x11opt.c,v 1.8 2003/02/16 12:43:37 isizaka Exp isizaka $
+ * 
+ * This file is part of "Ngraph for X11".
+ * 
+ * Copyright (C) 2002, Satoshi ISHIZAKA. isizaka@msa.biglobe.ne.jp
+ * 
+ * "Ngraph for X11" is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * "Ngraph for X11" is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ */
 
 /**
  *
  * $Log: x11opt.c,v $
+ * Revision 1.8  2003/02/16 12:43:37  isizaka
+ * for release 6.13.18
+ *
+ * Revision 1.7  2002/07/06 08:57:25  isizaka
+ * change to GPL.
+ *
+ * Revision 1.6  2001/07/14 17:44:50  isizaka
+ * for 6.03.14
+ *
+ * Revision 1.5  2001/03/23 12:17:43  isizaka
+ * for 6.3.13
+ *
  * Revision 1.4  1999/04/11 06:09:20  isizaka
  * *** empty log message ***
  *
@@ -95,8 +115,9 @@ void DefaultDialogClose(Widget w,void *data)
   char *buf;
   struct extprinter *pcur;
   struct script *scur;
-  char *driver,*option,*script;
+  char *driver,*ext,*option,*script;
   Position x,y,x0,y0;
+  Dimension w0,h0;
 
   d=(struct DefaultDialog *)data;
   if (d->ret!=IDOK) return;
@@ -110,10 +131,11 @@ void DefaultDialogClose(Widget w,void *data)
   if (XmToggleButtonGetState(XtNameToWidget(w,"*Geometry"))) {
     XtVaGetValues(MainWin,
                   XmNx,&x,XmNy,&y,
-                  XmNwidth,&(menulocal.menuwidth),
-                  XmNheight,&(menulocal.menuheight),NULL);
+                  XmNwidth,&w0,XmNheight,&h0,NULL);
     menulocal.menux=x;
     menulocal.menuy=y;
+    menulocal.menuwidth=w0;
+    menulocal.menuheight=h0;
     if ((buf=(char *)memalloc(64))!=NULL) {
       sprintf(buf,"menu_win=%d,%d,%d,%d",
         menulocal.menux,menulocal.menuy,
@@ -132,8 +154,9 @@ void DefaultDialogClose(Widget w,void *data)
   if (XmToggleButtonGetState(XtNameToWidget(w,"*ChildGeometry"))) {
     if (NgraphApp.FileWin.Win!=NULL) {
       XtVaGetValues(NgraphApp.FileWin.Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.filewidth),
-                         XmNheight,&(menulocal.fileheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+      menulocal.filewidth=w0;
+      menulocal.fileheight=h0;
       XtTranslateCoords(TopLevel,0,0,&x0,&y0);
       menulocal.filex=x-x0;
       menulocal.filey=y-y0;
@@ -147,8 +170,9 @@ void DefaultDialogClose(Widget w,void *data)
     }
     if (NgraphApp.AxisWin.Win!=NULL) {
       XtVaGetValues(NgraphApp.AxisWin.Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.axiswidth),
-                         XmNheight,&(menulocal.axisheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+      menulocal.axiswidth=w0;
+      menulocal.axisheight=h0;
       XtTranslateCoords(TopLevel,0,0,&x0,&y0);
       menulocal.axisx=x-x0;
       menulocal.axisy=y-y0;
@@ -162,8 +186,9 @@ void DefaultDialogClose(Widget w,void *data)
     }
     if (NgraphApp.LegendWin.Win!=NULL) {
       XtVaGetValues(NgraphApp.LegendWin.Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.legendwidth),
-                         XmNheight,&(menulocal.legendheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+      menulocal.legendwidth=w0;
+      menulocal.legendheight=h0;
       XtTranslateCoords(TopLevel,0,0,&x0,&y0);
       menulocal.legendx=x-x0;
       menulocal.legendy=y-y0;
@@ -177,8 +202,9 @@ void DefaultDialogClose(Widget w,void *data)
     }
     if (NgraphApp.MergeWin.Win!=NULL) {
       XtVaGetValues(NgraphApp.MergeWin.Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.mergewidth),
-                         XmNheight,&(menulocal.mergeheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+      menulocal.mergewidth=w0;
+      menulocal.mergeheight=h0;
       XtTranslateCoords(TopLevel,0,0,&x0,&y0);
       menulocal.mergex=x-x0;
       menulocal.mergey=y-y0;
@@ -192,8 +218,9 @@ void DefaultDialogClose(Widget w,void *data)
     }
     if (NgraphApp.InfoWin.Win!=NULL) {
       XtVaGetValues(NgraphApp.InfoWin.Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.dialogwidth),
-                         XmNheight,&(menulocal.dialogheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+      menulocal.dialogwidth=w0;
+      menulocal.dialogheight=h0;
       XtTranslateCoords(TopLevel,0,0,&x0,&y0);
       menulocal.dialogx=x-x0;
       menulocal.dialogy=y-y0;
@@ -207,8 +234,9 @@ void DefaultDialogClose(Widget w,void *data)
     }
     if (NgraphApp.CoordWin.Win!=NULL) {
       XtVaGetValues(NgraphApp.CoordWin.Win,XmNx,&x,XmNy,&y,
-                         XmNwidth,&(menulocal.coordwidth),
-                         XmNheight,&(menulocal.coordheight),NULL);
+                         XmNwidth,&w0,XmNheight,&h0,NULL);
+      menulocal.coordwidth=w0;
+      menulocal.coordheight=h0;
       XtTranslateCoords(TopLevel,0,0,&x0,&y0);
       menulocal.coordx=x-x0;
       menulocal.coordy=y-y0;
@@ -238,6 +266,10 @@ void DefaultDialogClose(Widget w,void *data)
       sprintf(buf,"viewer_show_ruler=%d",mxlocal->ruler);
       arrayadd(&conf,&buf);
     }
+    if ((buf=(char *)memalloc(20))!=NULL) {
+      sprintf(buf,"viewer_grid=%d",mxlocal->grid);
+      arrayadd(&conf,&buf);
+    }
     if ((buf=(char *)memalloc(30))!=NULL) {
       sprintf(buf,"backing_store=%d",mxlocal->backingstore);
       arrayadd(&conf,&buf);
@@ -248,11 +280,13 @@ void DefaultDialogClose(Widget w,void *data)
     while (pcur!=NULL) {
       if (pcur->driver==NULL) driver="";
       else driver=pcur->driver;
+      if (pcur->ext==NULL) ext="";
+      else ext=pcur->ext;
       if (pcur->option==NULL) option="";
       else option=pcur->option;
-      if ((buf=(char *)memalloc(strlen(pcur->name)+strlen(driver)
+      if ((buf=(char *)memalloc(strlen(pcur->name)+strlen(driver)+strlen(ext)
                                 +strlen(option)+20))!=NULL) {
-        sprintf(buf,"ext_driver=%s,%s,%s",pcur->name,driver,option);
+        sprintf(buf,"ext_driver=%s,%s,%s,%s",pcur->name,driver,ext,option);
         arrayadd(&conf,&buf);
       }
       pcur=pcur->next;
@@ -300,6 +334,18 @@ void DefaultDialogClose(Widget w,void *data)
       sprintf(buf,"save_with_merge=%d",menulocal.savewithmerge);
       arrayadd(&conf,&buf);
     }
+    if ((buf=(char *)memalloc(strlen(menulocal.expanddir)+20))!=NULL) {
+      sprintf(buf,"expand_dir=%s",menulocal.expanddir);
+      arrayadd(&conf,&buf);
+    }
+    if ((buf=(char *)memalloc(20))!=NULL) {
+      sprintf(buf,"expand=%d",menulocal.expand);
+      arrayadd(&conf,&buf);
+    }
+    if ((buf=(char *)memalloc(20))!=NULL) {
+      sprintf(buf,"ignore_path=%d",menulocal.ignorepath);
+      arrayadd(&conf,&buf);
+    }
   }
   replaceconfig("[x11menu]",&conf);
   arraydel2(&conf);
@@ -603,7 +649,6 @@ void PrefScriptDialogSetup(Widget w,void *data,int makewidget)
   XtManageChild(rc=XmCreateRowColumn(w,"rc",al,ac));
 
   ac=0;
-  XtSetArg(al[ac],XmNvisibleItemCount,10); ac++;
   XtSetArg(al[ac],XmNlistSizePolicy,XmCONSTANT); ac++;
   XtSetArg(al[ac],XmNscrollBarDisplayPolicy,XmSTATIC); ac++;
   XtSetArg(al[ac],XmNselectionPolicy,XmBROWSE_SELECT); ac++;
@@ -651,6 +696,10 @@ void SetDriverDialogSetupItem(Widget w,struct SetDriverDialog *d)
     XtVaSetValues(XtNameToWidget(w,"*option"),XmNvalue,"",NULL);
   else
     XtVaSetValues(XtNameToWidget(w,"*option"),XmNvalue,d->Driver->option,NULL);
+  if (d->Driver->ext==NULL)
+    XtVaSetValues(XtNameToWidget(w,"*ext"),XmNvalue,"",NULL);
+  else
+    XtVaSetValues(XtNameToWidget(w,"*ext"),XmNvalue,d->Driver->ext,NULL);
 }
 
 void SetDriverDialogBrowse(Widget w,XtPointer client_data,XtPointer call_data)
@@ -704,6 +753,13 @@ void SetDriverDialogSetup(Widget w,void *data,int makewidget)
   XtManageChild(XmCreateLabel(rc2,"Option",al,ac));
   ac=0;
   XtManageChild(XmCreateTextField(rc2,"option",al,ac));
+  ac=0;
+  XtSetArg(al[ac],XmNorientation,XmHORIZONTAL); ac++;
+  XtManageChild(rc2=XmCreateRowColumn(rc,"extrc",al,ac));
+  ac=0;
+  XtManageChild(XmCreateLabel(rc2,"Extension",al,ac));
+  ac=0;
+  XtManageChild(XmCreateTextField(rc2,"ext",al,ac));
   }
   SetDriverDialogSetupItem(w,d); 
 }
@@ -738,6 +794,14 @@ void SetDriverDialogClose(Widget w,void *data)
     d->Driver->driver=buf2;
   }
   XtFree(buf);
+  XtVaGetValues(XtNameToWidget(w,"*ext"),XmNvalue,&buf,NULL);
+  len=strlen(buf);
+  if ((buf2=(char *)memalloc(len+1))!=NULL) {
+    strcpy(buf2,buf);
+    memfree(d->Driver->ext);
+    d->Driver->ext=buf2;
+  }
+  XtFree(buf);
   XtVaGetValues(XtNameToWidget(w,"*option"),XmNvalue,&buf,NULL);
   len=strlen(buf);
   if ((buf2=(char *)memalloc(len+1))!=NULL) {
@@ -849,6 +913,7 @@ void PrefDriverDialogAdd(Widget w,XtPointer client_data,XtPointer call_data)
     fnew->name=NULL;
     fnew->driver=NULL;
     fnew->option=NULL;
+    fnew->ext=NULL;
     if (fprev==NULL) menulocal.extprinterroot=fnew;
     else fprev->next=fnew;
     SetDriverDialog(&DlgSetDriver,fnew);
@@ -879,7 +944,6 @@ void PrefDriverDialogSetup(Widget w,void *data,int makewidget)
   XtManageChild(rc=XmCreateRowColumn(w,"rc",al,ac));
 
   ac=0;
-  XtSetArg(al[ac],XmNvisibleItemCount,10); ac++;
   XtSetArg(al[ac],XmNlistSizePolicy,XmCONSTANT); ac++;
   XtSetArg(al[ac],XmNscrollBarDisplayPolicy,XmSTATIC); ac++;
   XtSetArg(al[ac],XmNselectionPolicy,XmBROWSE_SELECT); ac++;
@@ -914,20 +978,24 @@ void PrefDriverDialog(struct PrefDriverDialog *data)
 
 void MiscDialogSetupItem(Widget w,struct MiscDialog *d)
 {
-  int a;
-
   if (menulocal.editor!=NULL) 
     XtVaSetValues(XtNameToWidget(w,"*editor"),XmNvalue,menulocal.editor,NULL);
-  a=menulocal.changedirectory;
-  XmToggleButtonSetState(XtNameToWidget(w,"*directory"),a,TRUE);
-  a=menulocal.savehistory;
-  XmToggleButtonSetState(XtNameToWidget(w,"*history"),a,TRUE);
+  XmToggleButtonSetState(XtNameToWidget(w,"*directory"),
+                         menulocal.changedirectory,TRUE);
+  XmToggleButtonSetState(XtNameToWidget(w,"*history"),
+                         menulocal.savehistory,TRUE);
   XmListDeselectAllItems(GetComboBoxList(w,"*path"));
   XmListSelectPos(GetComboBoxList(w,"*path"),menulocal.savepath+1,TRUE);
   XtVaSetValues(XtNameToWidget(w,"*datafile"),XmNset,
                 menulocal.savewithdata,NULL);
   XtVaSetValues(XtNameToWidget(w,"*mergefile"),XmNset,
                 menulocal.savewithmerge,NULL);
+  XmToggleButtonSetState(XtNameToWidget(w,"*expand"),menulocal.expand,TRUE);
+  if (menulocal.expanddir!=NULL) 
+    XtVaSetValues(XtNameToWidget(w,"*expanddir"),XmNvalue,
+                  menulocal.expanddir,NULL);
+  XmToggleButtonSetState(XtNameToWidget(w,"*ignorepath"),
+                         menulocal.ignorepath,TRUE);
 }
 
 void MiscDialogSetup(Widget w,void *data,int makewidget)
@@ -936,9 +1004,7 @@ void MiscDialogSetup(Widget w,void *data,int makewidget)
   Cardinal ac;
   Widget rc,rc2,rc3,frame;
   struct MiscDialog *d;
-  char **enumlist;
   int j;
-  XmString s;
 
   d=(struct MiscDialog *)data;
   if (makewidget) {
@@ -993,12 +1059,25 @@ void MiscDialogSetup(Widget w,void *data,int makewidget)
   ac=0;
   XtManageChild(XmCreateToggleButton(rc3,"mergefile",al,ac));
 
-  enumlist=pathchar;
-  for (j=0;enumlist[j]!=NULL;j++) {
-    s=XmStringCreateLocalized(enumlist[j]);
-    XmListAddItem(GetComboBoxList(w,"*path"),s,0);
-    XmStringFree(s);
-  }
+  ac=0;
+  XtManageChild(frame=XmCreateFrame(rc,"lframe",al,ac));
+  ac=0;
+  XtSetArg(al[ac],XmNorientation,XmVERTICAL); ac++;
+  XtManageChild(rc3=XmCreateRowColumn(frame,"lrc",al,ac));
+  ac=0;
+  XtManageChild(XmCreateToggleButton(rc3,"expand",al,ac));
+  ac=0;
+  XtSetArg(al[ac],XmNorientation,XmHORIZONTAL); ac++;
+  XtManageChild(rc2=XmCreateRowColumn(rc3,"expandrc",al,ac));
+  ac=0;
+  XtManageChild(XmCreateLabel(rc2,"Expanddir",al,ac));
+  ac=0;
+  XtManageChild(XmCreateTextField(rc2,"expanddir",al,ac));
+  ac=0;
+  XtManageChild(XmCreateToggleButton(rc3,"ignorepath",al,ac));
+
+  for (j=0;pathchar[j]!=NULL;j++);
+  SetComboList(w,"*path",pathchar,j);
 
   }
   MiscDialogSetupItem(w,d); 
@@ -1027,12 +1106,10 @@ void MiscDialogClose(Widget w,void *data)
     menulocal.editor=buf2;
   }
   XtFree(buf);
-  a=XmToggleButtonGetState(XtNameToWidget(w,"*directory"));
-  a=a?TRUE:FALSE;
-  menulocal.changedirectory=a;
-  a=XmToggleButtonGetState(XtNameToWidget(w,"*history"));
-  a=a?TRUE:FALSE;
-  menulocal.savehistory=a;
+  menulocal.changedirectory=
+    XmToggleButtonGetState(XtNameToWidget(w,"*directory"));
+  menulocal.savehistory=
+    XmToggleButtonGetState(XtNameToWidget(w,"*history"));
   XmListGetSelectedPos(GetComboBoxList(w,"*path"),&selected,&num);
   if (num!=0) {
     a=selected[0]-1;
@@ -1043,6 +1120,18 @@ void MiscDialogClose(Widget w,void *data)
     XmToggleButtonGetState(XtNameToWidget(w,"*datafile"));
   menulocal.savewithmerge=
     XmToggleButtonGetState(XtNameToWidget(w,"*mergefile"));
+  menulocal.expand=
+    XmToggleButtonGetState(XtNameToWidget(w,"*expand"));
+  XtVaGetValues(XtNameToWidget(w,"*expanddir"),XmNvalue,&buf,NULL);
+  if (buf!=NULL) {
+    buf2=(char *)memalloc(strlen(buf)+1);
+    strcpy(buf2,buf);
+    memfree(menulocal.expanddir);
+    menulocal.expanddir=buf2;
+  }
+  XtFree(buf);
+  menulocal.ignorepath=
+    XmToggleButtonGetState(XtNameToWidget(w,"*ignorepath"));
   d->ret=ret;
 }
 
@@ -1054,7 +1143,7 @@ void MiscDialog(struct MiscDialog *data)
 
 void ExViewerDialogSetupItem(Widget w,struct ExViewerDialog *d)
 {
-  int a,dpi;
+  int dpi;
   char buf[64];
 
   dpi=menulocal.exwindpi;
@@ -1063,8 +1152,8 @@ void ExViewerDialogSetupItem(Widget w,struct ExViewerDialog *d)
   XtVaSetValues(XtNameToWidget(w,"*width"),XmNvalue,buf,NULL);
   sprintf(buf,"%d",menulocal.exwinheight);
   XtVaSetValues(XtNameToWidget(w,"*height"),XmNvalue,buf,NULL);
-  a=menulocal.exwinbackingstore;
-  XmToggleButtonSetState(XtNameToWidget(w,"*memory"),a,TRUE);
+  XmToggleButtonSetState(XtNameToWidget(w,"*memory"),
+                         menulocal.exwinbackingstore,TRUE);
 }
 
 void ExViewerDialogSetup(Widget w,void *data,int makewidget)
@@ -1138,9 +1227,8 @@ void ExViewerDialogClose(Widget w,void *data)
   a=strtol(buf,&endptr,10);
   if (endptr[0]=='\0') menulocal.exwinheight=a;
   XtFree(buf);
-  a=XmToggleButtonGetState(XtNameToWidget(w,"*memory"));
-  a=a?TRUE:FALSE;
-  menulocal.exwinbackingstore=a;
+  menulocal.exwinbackingstore=
+    XmToggleButtonGetState(XtNameToWidget(w,"*memory"));;
   d->ret=ret;
 }
 
@@ -1158,16 +1246,15 @@ void ViewerDialogSetupItem(Widget w,struct ViewerDialog *d)
 
   getobj(d->Obj,"dpi",d->Id,0,NULL,&(d->dpis));
   XmScaleSetValue(XtNameToWidget(w,"*dpi"),d->dpis);
-  a=mxlocal->ruler;
-  XmToggleButtonSetState(XtNameToWidget(w,"*ruler"),a,TRUE);
+  XmToggleButtonSetState(XtNameToWidget(w,"*ruler"),mxlocal->ruler,TRUE);
   getobj(d->Obj,"auto_redraw",d->Id,0,NULL,&a);
   XmToggleButtonSetState(XtNameToWidget(w,"*redraw"),a,TRUE);
   getobj(d->Obj,"redraw_flag",d->Id,0,NULL,&a);
   XmToggleButtonSetState(XtNameToWidget(w,"*loadfile"),a,TRUE);
   sprintf(buf,"%d",mxlocal->grid);
   XtVaSetValues(XtNameToWidget(w,"*grid"),XmNvalue,buf,NULL);
-  a=mxlocal->backingstore;
-  XmToggleButtonSetState(XtNameToWidget(w,"*memory"),a,TRUE);
+  XmToggleButtonSetState(XtNameToWidget(w,"*memory"),
+                         mxlocal->backingstore,TRUE);
 }
 
 void ViewerDialogSetup(Widget w,void *data,int makewidget)
