@@ -1,21 +1,38 @@
-/**
- *
- * $Id: x11print.c,v 1.2 1999/04/11 06:09:20 isizaka Exp $
- *
- * Copyright (C) 1997, Satoshi ISHIZAKA.
- *
- * This file is part of Ngraph
- *
- * This is free software; you can redistribute it and/or modify it.
- * However, it is prohibited to compile this on the "Windows" environment.
- *
- * Original author: Satoshi ISHIZAKA
- *                  isizaka@msa.biglobe.ne.jp
- **/
+/* 
+ * $Id: x11print.c,v 1.5 2003/02/16 12:43:37 isizaka Exp isizaka $
+ * 
+ * This file is part of "Ngraph for X11".
+ * 
+ * Copyright (C) 2002, Satoshi ISHIZAKA. isizaka@msa.biglobe.ne.jp
+ * 
+ * "Ngraph for X11" is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * "Ngraph for X11" is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ */
 
 /**
  *
  * $Log: x11print.c,v $
+ * Revision 1.5  2003/02/16 12:43:37  isizaka
+ * for release 6.13.18
+ *
+ * Revision 1.4  2002/07/06 08:57:25  isizaka
+ * change to GPL.
+ *
+ * Revision 1.3  2001/03/23 12:17:43  isizaka
+ * for 6.3.13
+ *
  * Revision 1.2  1999/04/11 06:09:20  isizaka
  * *** empty log message ***
  *
@@ -48,11 +65,12 @@
 
 void DriverDialogSelectCB(Widget w,XtPointer client_data,XtPointer call_data)
 {
-  int a,i;
+  int a,i,j;
   char *s;
   struct extprinter *pcur;
   struct DriverDialog *d;
   XmComboBoxCallbackStruct *dd;
+  char buf[1024];
   
   dd=(XmComboBoxCallbackStruct *)call_data;
   d=(struct DriverDialog *)client_data;
@@ -66,6 +84,17 @@ void DriverDialogSelectCB(Widget w,XtPointer client_data,XtPointer call_data)
   i=0;
   while (pcur!=NULL) {
     if (i==a) {
+      XtVaSetValues(XtNameToWidget(d->widget,"*file"),XmNvalue,"",NULL);
+      if ((pcur->ext!=NULL) && (pcur->ext[0]!='\0') 
+      && (NgraphApp.FileName!=NULL)) {
+        strcpy(buf,NgraphApp.FileName);
+        if (strchr(buf,'.')!=NULL) {
+          for (j=strlen(buf)-1;buf[j]!='.';j--);
+          buf[j]='\0';
+        }
+        strcat(buf,pcur->ext);
+        XtVaSetValues(XtNameToWidget(d->widget,"*file"),XmNvalue,buf,NULL);
+      }
       if (pcur->option==NULL) s="";
       else s=pcur->option;
       XtVaSetValues(XtNameToWidget(d->widget,"*option"),XmNvalue,s,NULL);
@@ -97,6 +126,7 @@ void DriverDialogSetup(Widget w,void *data,int makewidget)
   XmString s;
   struct DriverDialog *d;
   struct extprinter *pcur;
+  int j;
  
   d=(struct DriverDialog *)data;
   if (makewidget) {
@@ -134,12 +164,15 @@ void DriverDialogSetup(Widget w,void *data,int makewidget)
   }
   XmListDeleteAllItems(GetComboBoxList(w,"*driver"));
   pcur=menulocal.extprinterroot;
+  j=0;
   while (pcur!=NULL) {
     s=XmStringCreateLocalized(pcur->name);
     XmListAddItem(GetComboBoxList(w,"*driver"),s,0);
     XmStringFree(s);
     pcur=pcur->next;
+    j++;
   }
+  SetComboBoxVisibleItemCount(w,"*driver",j);
   XmListSelectPos(GetComboBoxList(w,"*driver"),1,TRUE);
 }
 
@@ -280,7 +313,8 @@ void PrintDialogSetup(Widget w,void *data,int makewidget)
   XmString s;
   struct PrintDialog *d;
   struct prnprinter *pcur;
- 
+  int j; 
+
   d=(struct PrintDialog *)data;
   if (makewidget) {
     ac=0;
@@ -314,12 +348,15 @@ void PrintDialogSetup(Widget w,void *data,int makewidget)
 
   XmListDeleteAllItems(GetComboBoxList(w,"*driver"));
   pcur=menulocal.prnprinterroot;
+  j=0;
   while (pcur!=NULL) {
     s=XmStringCreateLocalized(pcur->name);
     XmListAddItem(GetComboBoxList(w,"*driver"),s,0);
     XmStringFree(s);
     pcur=pcur->next;
+    j++;
   }
+  SetComboBoxVisibleItemCount(w,"*driver",j);
   XmListSelectPos(GetComboBoxList(w,"*driver"),1,TRUE);
 }
 
@@ -379,6 +416,54 @@ void PrintDialog(struct PrintDialog *data,
   data->Id=id;
 }
 
+void OutputDataDialogSetupItem(Widget w,struct OutputDataDialog *d)
+{
+  char buf[256];
+
+  sprintf(buf,"%d",d->div);
+  XtVaSetValues(XtNameToWidget(w,"*div"),XmNvalue,buf,NULL);
+}
+
+void OutputDataDialogSetup(Widget w,void *data,int makewidget)
+{
+  Arg al[20];
+  Cardinal ac;
+  Widget rc;
+  struct OutputDataDialog *d;
+  
+  d=(struct OutputDataDialog *)data;
+  if (makewidget) {
+    ac=0;
+    XtSetArg(al[ac],XmNorientation,XmHORIZONTAL); ac++;
+    XtManageChild(rc=XmCreateRowColumn(w,"rc",al,ac));
+    ac=0;
+    XtManageChild(XmCreateLabel(rc,"Div",al,ac));
+    ac=0;
+    XtManageChild(XmCreateTextField(rc,"div",al,ac));
+  }
+  OutputDataDialogSetupItem(w,d);
+}
+
+void OutputDataDialogClose(Widget w,void *data)
+{
+  struct OutputDataDialog *d;
+  int a;
+  char *buf,*endptr;
+  
+  d=(struct OutputDataDialog *)data;
+  if (d->ret!=IDOK) return;
+  XtVaGetValues(XtNameToWidget(d->widget,"*div"),XmNvalue,&buf,NULL);
+  a=strtol(buf,&endptr,10);
+  if (endptr[0]=='\0') d->div=a;
+  XtFree(buf);
+}
+
+void OutputDataDialog(struct OutputDataDialog *data,int div)
+{
+  data->SetupWindow=OutputDataDialogSetup;
+  data->CloseWindow=OutputDataDialogClose;
+  data->div=div;
+}
 
 void CmOutputDriver(int print)
 {
@@ -388,6 +473,7 @@ void CmOutputDriver(int print)
   int GC;
   struct narray *drawrable;
   int i,ret;
+  struct savedstdio stdio;
 
   if (menulock || globallock ) return;
   if (SetFileHidden()) {
@@ -425,10 +511,12 @@ void CmOutputDriver(int print)
         sprintf(device,"gra2prn:^%d",g2woid);
         putobj(graobj,"device",id,device);
         SetStatusBar("Printing.");
+        ignorestdio(&stdio);
         getobj(graobj,"open",id,0,NULL,&GC);
         exeobj(graobj,"draw",id,0,NULL);
         exeobj(graobj,"flush",id,0,NULL);
         exeobj(graobj,"close",id,0,NULL);
+        restorestdio(&stdio);
         delobj(graobj,id);
         ResetStatusBar();
       }
@@ -572,10 +660,10 @@ void CmPrintDataFile()
 {
   struct objlist *obj;
   int id;
-  FILE *fp;
   double dx,dy,d2,d3;
-  int type,ftype,sx,sy,s2,s3;
+  int type,div;
   char *buf,*file;
+  char *argv[3];
 
   if (menulock || globallock ) return;
   if ((obj=chkobject("file"))==NULL) return;
@@ -584,6 +672,13 @@ void CmPrintDataFile()
   if (DialogExecute(TopLevel,&DlgCopy)==IDOK) {
     id=DlgCopy.sel;
     if ((id>=0) && (id<=chkobjlastinst(obj))) {
+      div=10;
+      getobj(obj,"type",id,0,NULL,&type);
+      if (type==3) {
+        OutputDataDialog(&DlgOutputData,div);
+        if (DialogExecute(TopLevel,&DlgOutputData)!=IDOK) return;
+        div=DlgOutputData.div;
+      }
       if (nGetSaveFileName(TopLevel,"Data file",NULL,NULL,NULL,
           &file,"*",menulocal.changedirectory)==IDOK) {
         if (access(file,04)==0) {
@@ -604,56 +699,12 @@ void CmPrintDataFile()
             }
           }
         }
-        if ((fp=nfopen(file,"wt"))!=NULL) {
-          getobj(obj,"type",id,0,NULL,&type);
-          switch (type) {
-          case 4: case 5: case 6: case 7:
-            ftype=1;
-            break;
-          case 8:
-            ftype=2;
-            break;
-          case 9:
-            ftype=3;
-            break;
-          default:
-            ftype=0;
-            break;
-          }
-          SetStatusBar("Making data file.");
-          exeobj(obj,"opendata",id,0,NULL);
-          while (exeobj(obj,"getdata",id,0,NULL)==0) {
-            getobj(obj,"data_x",id,0,NULL,&dx);
-            getobj(obj,"data_y",id,0,NULL,&dy);
-            getobj(obj,"stat_x",id,0,NULL,&sx);
-            getobj(obj,"stat_y",id,0,NULL,&sy);
-            if (ftype!=0) {
-              getobj(obj,"data_2",id,0,NULL,&d2);
-              getobj(obj,"data_3",id,0,NULL,&d3);
-              getobj(obj,"stat_2",id,0,NULL,&s2);
-              getobj(obj,"stat_3",id,0,NULL,&s3);
-            }
-            if ((ftype==0) && (sx==MNOERR) && (sy==MNOERR)) {
-              fprintf(fp,"%.15e %.15e\n",dx,dy);
-            } else if ((sx==MNOERR) && (sy==MNOERR) 
-                    && (s2==MNOERR) && (s3==MNOERR)) {
-              switch (ftype) {
-              case 1:
-                fprintf(fp,"%.15e %.15e %.15e %.15e\n",dx,dy,d2,d3);
-                break;
-              case 2:
-                fprintf(fp,"%.15e %.15e %.15e %.15e\n",dx,d2-dx,d3-dx,dy);
-                break;
-              case 3:
-                fprintf(fp,"%.15e %.15e %.15e %.15e\n",dx,dy,d2-dy,d3-dy);
-                break;
-              }
-            }
-          }
-          exeobj(obj,"closedata",id,0,NULL);
-          ResetStatusBar();
-        }
-        fclose(fp);
+        SetStatusBar("Making data file.");
+        argv[0]=(char *)file;
+        argv[1]=(char *)&div;
+        argv[2]=NULL;
+        exeobj(obj,"output_file",id,2,argv);
+        ResetStatusBar();
       }
       free(file);
     }
