@@ -1,6 +1,6 @@
 /**
  *
- * $Id: gra2ps.c,v 1.15 2003/08/15 12:04:26 isizaka Exp isizaka $
+ * $Id: gra2ps.c,v 1.16 2009/04/03 14:07:43 isizaka Exp isizaka $
  *
  * This is free software; you can redistribute it and/or modify it.
  *
@@ -11,6 +11,9 @@
 /**
  *
  * $Log: gra2ps.c,v $
+ * Revision 1.16  2009/04/03 14:07:43  isizaka
+ * add viewc
+ *
  * Revision 1.15  2003/08/15 12:04:26  isizaka
  * 2.03.17
  *
@@ -77,7 +80,7 @@
 #define CONFSEP "/"
 #define NSTRLEN 256
 #define LINETOLIMIT 500
-#define VERSION "2.03.17"
+#define VERSION "2.03.20"
 
 #define TRUE  1
 #define FALSE 0
@@ -106,6 +109,7 @@ int paper=A4;
 int rotate=FALSE;
 int bottom=29700;
 int sjis=FALSE;
+int font_slant=12;
 
 int printfstderr(char *fmt,...)
 {
@@ -866,7 +870,7 @@ void draw(char code,int *cpar,char *cstr)
   struct fontmap *fcur;
   unsigned int jis,R,G,B;
   int c1,c2,sx,sy;
-  double d;
+  double d,ftan;
 
   if (lineto) {
     if (code!='T') {
@@ -983,8 +987,12 @@ void draw(char code,int *cpar,char *cstr)
     printfstderr("%c%s\n",'%',cstr);
     break;
   case 'V':
-    printfstdout("%d %d %d %d %d view\n",
-    cpar[1],cpar[2],cpar[3]-cpar[1],cpar[4]-cpar[2],cpar[5]);
+    if (color)
+      printfstdout("%d %d %d %d %d viewc\n",
+      cpar[1],cpar[2],cpar[3]-cpar[1],cpar[4]-cpar[2],cpar[5]);
+    else
+      printfstdout("%d %d %d %d %d view\n",
+      cpar[1],cpar[2],cpar[3]-cpar[1],cpar[4]-cpar[2],cpar[5]);
     break;
   case 'A':
     if (cpar[1]==0) printfstdout("[] 0 ");
@@ -1105,11 +1113,14 @@ void draw(char code,int *cpar,char *cstr)
     sprintf(textspace,"%g %g",cpar[2]*cos(MPI*cpar[3]/18000.0)*25.4/72,
                              -cpar[2]*sin(MPI*cpar[3]/18000.0)*25.4/72);
     if ((fonttype==ITALIC) || (fonttype==BOLDITALIC)) {
+      ftan=tan(font_slant*MPI/180.0);
       printfstdout("[%g %g %g %g 0 0] ",
          cpar[1]*cos(MPI*cpar[3]/18000.0)*25.4/72,
         -cpar[1]*sin(MPI*cpar[3]/18000.0)*25.4/72,
-        -cpar[1]*(sin(MPI*cpar[3]/18000.0)-0.36*cos(MPI*cpar[3]/18000.0))*25.4/72,
-        -cpar[1]*(cos(MPI*cpar[3]/18000.0)+0.36*sin(MPI*cpar[3]/18000.0))*25.4/72);
+        -cpar[1]*(sin(MPI*cpar[3]/18000.0)
+         -ftan*cos(MPI*cpar[3]/18000.0))*25.4/72,
+        -cpar[1]*(cos(MPI*cpar[3]/18000.0)
+         +ftan*sin(MPI*cpar[3]/18000.0))*25.4/72);
     } else {
       printfstdout("[%g %g %g %g 0 0] ",
          cpar[1]*cos(MPI*cpar[3]/18000.0)*25.4/72,
@@ -1268,6 +1279,8 @@ int main(int argc,char **argv)
   char *lib,*home;
   char *tmpname;
   int ch;
+  char *endptr;
+  int a;
 
   printfstderr("Ngraph - PostScript(R) Printer Driver version: "VERSION"\n");
 
@@ -1369,6 +1382,13 @@ int main(int argc,char **argv)
     case 'r':
       rotate=TRUE;
       break;
+    case 's':
+      if ((i+1)<argc) {
+        a=strtol(argv[i+1],&endptr,10);
+        if ((endptr[0]=='\0') && (0<=a) && (a<=60)) font_slant=a;
+        i++;
+      }
+      break;
     default:
       printfstderr("unknown option `%s'.\n",argv[i]);
       free(includefile);
@@ -1387,7 +1407,8 @@ int main(int argc,char **argv)
     printfstderr(" -e                             : EPSF output\n");
     printfstderr(" -p a3|a4|b4|a5|b5|letter|legal : paper\n");
     printfstderr(" -l                             : landscape\n");
-    printfstderr(" -r                             : rotate 90 degree\n");
+    printfstderr(" -r                             : rotate by 90 degree\n");
+    printfstderr(" -s theta                       : slant angle (degree)\n");
     free(includefile);
     free(libdir);
     free(homedir);
